@@ -4,15 +4,15 @@ from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.core.cache import cache
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .currencies import CURRENCIES
 
-BASE_CURRENCY = getattr(settings, 'OPENEXCHANGERATES_BASE_CURRENCY', 'USD')
+BASE_CURRENCY = getattr(settings, "OPENEXCHANGERATES_BASE_CURRENCY", "USD")
 CACHE_KEY = getattr(
-    settings, 'OPENEXCHANGERATES_CACHE_KEY',
-    'openexchangerates_conversion_rates')
-CACHE_TIME = getattr(settings, 'OPENEXCHANGERATES_CACHE_TTL', 60*60)
+    settings, "OPENEXCHANGERATES_CACHE_KEY", "openexchangerates_conversion_rates"
+)
+CACHE_TIME = getattr(settings, "OPENEXCHANGERATES_CACHE_TTL", 60 * 60)
 
 
 def get_rates(qs, force_refresh=False):
@@ -24,13 +24,12 @@ def get_rates(qs, force_refresh=False):
 
 
 class CachingManager(models.Manager):
-
     def get_rate(self, to_currency):  # noqa
         all_rates = get_rates(self.all())
         try:
             return all_rates[to_currency]
         except KeyError:
-            msg = 'ConversionRate for %s does not exist' % to_currency
+            msg = "ConversionRate for %s does not exist" % to_currency
             raise ConversionRate.DoesNotExist(msg)
 
 
@@ -39,38 +38,40 @@ class ConversionRate(models.Model):
     base_currency = BASE_CURRENCY
 
     to_currency = models.CharField(
-        _('To'), max_length=3, db_index=True,
-        choices=CURRENCIES, unique=True)
+        _("To"), max_length=3, db_index=True, choices=CURRENCIES, unique=True
+    )
 
-    rate = models.DecimalField(
-        _('Conversion rate'), max_digits=20, decimal_places=12)
+    rate = models.DecimalField(_("Conversion rate"), max_digits=20, decimal_places=12)
 
     modified_at = models.DateTimeField(auto_now=True)
 
     objects = CachingManager()
 
     class Meta:
-        ordering = ['to_currency']
+        ordering = ["to_currency"]
 
     def save(self, *args, **kwargs):  # noqa
-        """ Save the model instance but only on successful validation. """
+        """Save the model instance but only on successful validation."""
         self.full_clean()
         super(ConversionRate, self).save(*args, **kwargs)
 
     def clean(self):  # noqa
         if self.rate <= Decimal(0):
-            raise ValidationError('Conversion rate has to be positive')
+            raise ValidationError("Conversion rate has to be positive")
         if self.base_currency == self.to_currency:
-            raise ValidationError(
-                'Can\'t set a conversion rate for the same currency')
+            raise ValidationError("Can't set a conversion rate for the same currency")
         super(ConversionRate, self).clean()
 
     def __str__(self):  # noqa
-        return '1 %s = %.04f %s' % (
-            self.base_currency, self.rate, self.to_currency)
+        return "1 %s = %.04f %s" % (self.base_currency, self.rate, self.to_currency)
 
     def __repr__(self):  # noqa
         format_template = (
-            'ConversionRate(pk=%r, base_currency=%r, to_currency=%r, rate=%r)')
+            "ConversionRate(pk=%r, base_currency=%r, to_currency=%r, rate=%r)"
+        )
         return format_template % (
-            self.pk, self.base_currency, self.to_currency, self.rate)
+            self.pk,
+            self.base_currency,
+            self.to_currency,
+            self.rate,
+        )
